@@ -12,6 +12,7 @@ import errno
 import codecs
 import signal
 import urllib
+import locale
 import logging
 import datetime
 import optparse
@@ -108,12 +109,14 @@ except ImportError:
 from gtimelog import __version__
 
 
+legacy_default_home = '~/.gtimelog'
+
+
 # This is to let people run GTimeLog without having to install it
 resource_dir = os.path.dirname(os.path.realpath(__file__))
 ui_file = os.path.join(resource_dir, "gtimelog.ui")
 icon_file_bright = os.path.join(resource_dir, "gtimelog-small-bright.png")
 icon_file_dark = os.path.join(resource_dir, "gtimelog-small.png")
-default_home = '~/.gtimelog'
 
 # This is for distribution packages
 if not os.path.exists(ui_file):
@@ -281,11 +284,14 @@ class TimeWindow(object):
                     self.earliest_timestamp = time
                 if self.min_timestamp <= time < self.max_timestamp:
                     self.items.append((time, entry))
-        # The entries really should be already sorted in the file
-        # XXX: instead of quietly resorting them we should inform the user
+        # There's code that relies on entries being sorted.  The entries really
+        # should be already sorted in the file, but sometimes the user edits
+        # timelog.txt directly and introduces errors.
+        # XXX: instead of quietly resorting them we should inform the user if
+        # there are errors
         # Note that we must preserve the relative order of entries with
         # the same timestamp: https://bugs.launchpad.net/gtimelog/+bug/708825
-        self.items.sort(key=itemgetter(0)) # there's code that relies on them being sorted
+        self.items.sort(key=itemgetter(0))
         f.close()
 
     def last_time(self):
@@ -574,7 +580,7 @@ class Reports(object):
         if entries:
             categories = entries.keys()
             categories.sort()
-            if categories[0] == None:
+            if categories[0] is None:
                 categories = categories[1:]
                 categories.append('No category')
                 e = entries.pop(None)
@@ -594,7 +600,8 @@ class Reports(object):
                     entry = entry[:1].upper() + entry[1:]
                     if estimated_column:
                         print >> output, (u"  %-46s  %-14s  %s" %
-                                    (entry, '-', format_duration_short(duration)))
+                                    (entry, '-',
+                                     format_duration_short(duration)))
                     else:
                         print >> output, (u"  %-61s  %+5s" %
                                     (entry, format_duration_short(duration)))
@@ -700,25 +707,25 @@ class Reports(object):
     def weekly_report_categorized(self, output, email, who,
                                   estimated_column=False):
         """Format a weekly report with entries displayed  under categories."""
-        week = self.window.min_timestamp.strftime('%V')
-        subject = 'Weekly report for %s (week %s)' % (who, week)
+        week = self.window.min_timestamp.isocalendar()[1]
+        subject = u'Weekly report for {} (week {:0>2})'.format(who, week)
         return self._categorizing_report(output, email, who, subject,
                                          period_name='week',
                                          estimated_column=estimated_column)
 
     def monthly_report_categorized(self, output, email, who,
-                                  estimated_column=False):
+                                   estimated_column=False):
         """Format a monthly report with entries displayed  under categories."""
         month = self.window.min_timestamp.strftime('%Y/%m')
-        subject = 'Monthly report for %s (%s)' % (who, month)
+        subject = u'Monthly report for %s (%s)' % (who, month)
         return self._categorizing_report(output, email, who, subject,
                                          period_name='month',
                                          estimated_column=estimated_column)
 
     def weekly_report_plain(self, output, email, who, estimated_column=False):
         """Format a weekly report ."""
-        week = self.window.min_timestamp.strftime('%V')
-        subject = 'Weekly report for %s (week %s)' % (who, week)
+        week = self.window.min_timestamp.isocalendar()[1]
+        subject = u'Weekly report for {} (week {:0>2})'.format(who, week)
         return self._plain_report(output, email, who, subject,
                                   period_name='week',
                                   estimated_column=estimated_column)
@@ -726,7 +733,7 @@ class Reports(object):
     def monthly_report_plain(self, output, email, who, estimated_column=False):
         """Format a monthly report ."""
         month = self.window.min_timestamp.strftime('%Y/%m')
-        subject = 'Monthly report for %s (%s)' % (who, month)
+        subject = u'Monthly report for %s (%s)' % (who, month)
         return self._plain_report(output, email, who, subject,
                                   period_name='month',
                                   estimated_column=estimated_column)
@@ -742,12 +749,12 @@ class Reports(object):
         # would give us translated names
         weekday_names = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun']
         weekday = weekday_names[window.min_timestamp.weekday()]
-        week = window.min_timestamp.strftime('%V')
-        print >> output, "To: %(email)s" % {'email': email}
-        print >> output, ("Subject: %(date)s report for %(who)s"
-                          " (%(weekday)s, week %(week)s)"
-                          % {'date': window.min_timestamp.strftime('%Y-%m-%d'),
-                             'weekday': weekday, 'week': week, 'who': who})
+        week = window.min_timestamp.isocalendar()[1]
+        print >> output, u"To: {email}".format(email=email)
+        print >> output, (u"Subject: {:%Y-%m-%d} report for {who}"
+                          u" ({weekday}, week {week:0>2})".format(
+                          window.min_timestamp, who=who,
+                          weekday=weekday, week=week))
         print >> output
         items = list(window.all_entries())
         if not items:
@@ -821,7 +828,10 @@ class TimeLog(object):
             return False
 
     def get_mtime(self):
-        """Return the mtime of self.filename, or None if the file doesn't exist."""
+        """Return the mtime of self.filename, if it exists.
+
+        Returns None if the file doesn't exist.
+        """
         try:
             return os.stat(self.filename).st_mtime
         except OSError:
@@ -952,7 +962,10 @@ class TaskList(object):
             return False
 
     def get_mtime(self):
-        """Return the mtime of self.filename, or None if the file doesn't exist."""
+        """Return the mtime of self.filename, if it exists.
+
+        Returns None if the file doesn't exist.
+        """
         try:
             return os.stat(self.filename).st_mtime
         except OSError:
@@ -1029,6 +1042,8 @@ class RemoteTaskList(TaskList):
 class Settings(object):
     """Configurable settings for GTimeLog."""
 
+    _encoding = locale.getpreferredencoding()
+
     # Insane defaults
     email = 'activity-list@example.com'
     name = 'Anonymous'
@@ -1056,18 +1071,41 @@ class Settings(object):
 
     report_style = 'plain'
 
-    def get_config_dir(self):
+    def check_legacy_config(self):
         envar_home = os.environ.get('GTIMELOG_HOME')
-        return os.path.expanduser(envar_home if envar_home else default_home)
+        if envar_home is not None:
+            return os.path.expanduser(envar_home)
+        if os.path.isdir(os.path.expanduser(legacy_default_home)):
+            return os.path.expanduser(legacy_default_home)
+        return None
+
+    # http://standards.freedesktop.org/basedir-spec/basedir-spec-latest.html
+
+    def get_config_dir(self):
+        legacy = self.check_legacy_config()
+        if legacy:
+            return legacy
+        xdg = os.environ.get('XDG_CONFIG_HOME') or '~/.config'
+        return os.path.join(os.path.expanduser(xdg), 'gtimelog')
+
+    def get_data_dir(self):
+        legacy = self.check_legacy_config()
+        if legacy:
+            return legacy
+        xdg = os.environ.get('XDG_DATA_HOME') or '~/.local/share'
+        return os.path.join(os.path.expanduser(xdg), 'gtimelog')
 
     def get_config_file(self):
         return os.path.join(self.get_config_dir(), 'gtimelogrc')
 
+    def get_timelog_file(self):
+        return os.path.join(self.get_data_dir(), 'timelog.txt')
+
     def _config(self):
         config = ConfigParser.RawConfigParser()
         config.add_section('gtimelog')
         config.set('gtimelog', 'list-email', self.email)
-        config.set('gtimelog', 'name', self.name)
+        config.set('gtimelog', 'name', self.name.encode(self._encoding))
         config.set('gtimelog', 'editor', self.editor)
         config.set('gtimelog', 'mailer', self.mailer)
         config.set('gtimelog', 'spreadsheet', self.spreadsheet)
@@ -1084,8 +1122,10 @@ class Settings(object):
         config.set('gtimelog', 'show_office_hours',
                    str(self.show_office_hours))
         config.set('gtimelog', 'show_tray_icon', str(self.show_tray_icon))
-        config.set('gtimelog', 'prefer_app_indicator', str(self.prefer_app_indicator))
-        config.set('gtimelog', 'prefer_old_tray_icon', str(self.prefer_old_tray_icon))
+        config.set('gtimelog', 'prefer_app_indicator',
+                   str(self.prefer_app_indicator))
+        config.set('gtimelog', 'prefer_old_tray_icon',
+                   str(self.prefer_old_tray_icon))
         config.set('gtimelog', 'report_style', str(self.report_style))
         config.set('gtimelog', 'start_in_tray', str(self.start_in_tray))
         return config
@@ -1094,7 +1134,7 @@ class Settings(object):
         config = self._config()
         config.read([filename])
         self.email = config.get('gtimelog', 'list-email')
-        self.name = config.get('gtimelog', 'name')
+        self.name = config.get('gtimelog', 'name').decode(self._encoding)
         self.editor = config.get('gtimelog', 'editor')
         self.mailer = config.get('gtimelog', 'mailer')
         self.spreadsheet = config.get('gtimelog', 'spreadsheet')
@@ -1395,7 +1435,10 @@ class MainWindow:
         # Try to prevent timer routines mucking with the buffer while we're
         # mucking with the buffer.  Not sure if it is necessary.
         self.lock = False
-        self.chronological = settings.chronological and not settings.summary_view
+        # I'm representing a tristate with two booleans (for config file
+        # backwards compat), let's normalize nonsensical states.
+        self.chronological = (settings.chronological
+                              and not settings.summary_view)
         self.summary_view = settings.summary_view
         self.show_tasks = settings.show_tasks
         self.looking_at_date = None
@@ -1512,7 +1555,8 @@ class MainWindow:
         else:
             today = self.looking_at_date
             window = self.timelog.window_for_day(today)
-        today = today.strftime('%A, %Y-%m-%d (week %V)')
+        today = "{:%A, %Y-%m-%d} (week {:0>2})".format(today,
+                                                       today.isocalendar()[1])
         self.current_view_label.set_text(today)
         if self.chronological:
             for item in window.all_entries():
@@ -1594,7 +1638,7 @@ class MainWindow:
             self.w('\nAt office today: ')
             hours = datetime.timedelta(hours=self.settings.hours)
             total = total_slacking + total_work
-            self.w("%s " % format_duration(total), 'duration' )
+            self.w("%s " % format_duration(total), 'duration')
             self.w('(')
             if total > hours:
                 self.w(format_duration(total - hours), 'duration')
@@ -1830,7 +1874,7 @@ class MainWindow:
         """
         if self.calendar_dialog.run() == GTK_RESPONSE_OK:
             y, m1, d = self.calendar.get_date()
-            day = datetime.date(y, m1+1, d)
+            day = datetime.date(y, m1 + 1, d)
         else:
             day = None
         self.calendar_dialog.hide()
@@ -2227,7 +2271,8 @@ def main():
         print 'Toolkit: %s' % toolkit
         print 'Gtk+ version: %s' % gtk_version
         print 'D-Bus available: %s' % ('yes' if dbus else 'no')
-        print 'GTimeLog directory: %s' % Settings().get_config_dir()
+        print 'Config directory: %s' % Settings().get_config_dir()
+        print 'Data directory: %s' % Settings().get_data_dir()
 
     if opts.ignore_dbus:
         dbus = None
@@ -2271,13 +2316,21 @@ def main():
 
     settings = Settings()
     configdir = settings.get_config_dir()
+    datadir = settings.get_data_dir()
     try:
-        # Create it if it doesn't exist.
+        # Create configdir if it doesn't exist.
         os.makedirs(configdir)
     except OSError as error:
         if error.errno != errno.EEXIST:
             # XXX: not the most friendly way of error reporting for a GUI app
             raise
+    try:
+        # Create datadir if it doesn't exist.
+        os.makedirs(datadir)
+    except OSError as error:
+        if error.errno != errno.EEXIST:
+            raise
+
     settings_file = settings.get_config_file()
     if not os.path.exists(settings_file):
         if opts.debug:
@@ -2288,20 +2341,20 @@ def main():
             print 'Loading settings from %s' % settings_file
         settings.load(settings_file)
     if opts.debug:
-        print 'Loading time log from %s' % os.path.join(configdir, 'timelog.txt')
+        print 'Loading time log from %s' % settings.get_timelog_file()
         print 'Assuming date changes at %s' % settings.virtual_midnight
-    timelog = TimeLog(os.path.join(configdir, 'timelog.txt'),
+    timelog = TimeLog(settings.get_timelog_file(),
                       settings.virtual_midnight)
     if settings.task_list_url:
         if opts.debug:
             print 'Loading cached remote tasks from %s' % (
-                               os.path.join(configdir, 'remote-tasks.txt'))
+                               os.path.join(datadir, 'remote-tasks.txt'))
         tasks = RemoteTaskList(settings.task_list_url,
-                               os.path.join(configdir, 'remote-tasks.txt'))
+                               os.path.join(datadir, 'remote-tasks.txt'))
     else:
         if opts.debug:
-            print 'Loading tasks from %s' % os.path.join(configdir, 'tasks.txt')
-        tasks = TaskList(os.path.join(configdir, 'tasks.txt'))
+            print 'Loading tasks from %s' % os.path.join(datadir, 'tasks.txt')
+        tasks = TaskList(os.path.join(datadir, 'tasks.txt'))
     main_window = MainWindow(timelog, settings, tasks)
     start_in_tray = False
     if settings.show_tray_icon:
